export declare const DASHBUILDER_SCHEMA: {
    $id: string;
    $schema: string;
    description: string;
    type: string;
    properties: {
        pages: {
            description: string;
            type: string;
            items: {
                $ref: string;
            };
        };
        datasets: {
            type: string;
            description: string;
            items: {
                $ref: string;
            };
        };
        navTree: {
            description: string;
            $ref: string;
        };
        properties: {
            description: string;
            $ref: string;
        };
        global: {
            description: string;
            $ref: string;
        };
    };
    required: string[];
    definitions: {
        GlobalProperties: {
            type: string;
            properties: {
                mode: {
                    $ref: string;
                };
                settings: {
                    $ref: string;
                };
            };
            title: string;
        };
        Page: {
            type: string;
            properties: {
                name: {
                    type: string;
                };
                components: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                rows: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                properties: {
                    $ref: string;
                };
            };
            title: string;
        };
        PageComponent: {
            type: string;
            properties: {
                html: {
                    type: string;
                };
                settings: {
                    $ref: string;
                };
            };
            title: string;
        };
        Row: {
            type: string;
            properties: {
                columns: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                properties: {
                    $ref: string;
                };
            };
            required: string[];
            title: string;
        };
        RowColumn: {
            type: string;
            properties: {
                span: {
                    type: string[];
                };
                components: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                rows: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                properties: {
                    $ref: string;
                };
            };
            required: string[];
            title: string;
        };
        ColumnComponent: {
            type: string;
            anyOf: ({
                properties: {
                    html: {
                        type: string;
                    };
                    type: {
                        $ref: string;
                        type?: undefined;
                    };
                    settings: {
                        $ref: string;
                    };
                };
            } | {
                properties: {
                    html: {
                        type: string;
                    };
                    type: {
                        type: string;
                        $ref?: undefined;
                    };
                    settings: {
                        $ref: string;
                    };
                };
            })[];
            title: string;
        };
        Dataset: {
            type: string;
            properties: {
                uuid: {
                    type: string;
                };
                url: {
                    type: string;
                    format: string;
                };
                content: {
                    type: string;
                };
                columns: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                expression: {
                    type: string;
                    minLength: number;
                };
                cacheEnabled: {
                    type: string[];
                };
                refreshTime: {
                    type: string;
                };
            };
            oneOf: {
                properties: {
                    content: {
                        type: string;
                    };
                    url: {
                        type: string;
                        format: string;
                    };
                };
                required: string[];
                not: {
                    required: string[];
                };
            }[];
            required: string[];
            title: string;
        };
        DatasetColumn: {
            type: string;
            properties: {
                id: {
                    type: string;
                };
                type: {
                    $ref: string;
                };
            };
            required: string[];
            title: string;
        };
        DataSetLookup: {
            type: string;
            properties: {
                uuid: {
                    type: string;
                };
                rowCount: {
                    type: string;
                };
                rowOffset: {
                    type: string;
                };
                sort: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                filter: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                group: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
            };
            required: string[];
            title: string;
        };
        SettingsFilter: {
            type: string;
            properties: {
                enabled: {
                    type: string[];
                };
                listening: {
                    type: string[];
                };
                notification: {
                    type: string[];
                };
                selfapply: {
                    type: string[];
                };
            };
            required: string[];
            title: string;
        };
        SettingsColumn: {
            type: string;
            properties: {
                id: {
                    type: string;
                };
                name: {
                    type: string;
                };
                expression: {
                    type: string;
                };
                pattern: {
                    type: string;
                };
            };
            required: string[];
            title: string;
        };
        SettingsTable: {
            type: string;
            properties: {
                pageSize: {
                    type: string;
                };
                show_column_picker: {
                    type: string;
                };
                sort: {
                    $ref: string;
                };
            };
            title: string;
        };
        TableSort: {
            type: string;
            properties: {
                enabled: {
                    type: string[];
                };
                columnId: {
                    type: string;
                };
                order: {
                    $ref: string;
                };
            };
            required: string[];
            title: string;
        };
        Sort: {
            type: string;
            properties: {
                column: {
                    type: string;
                };
                order: {
                    $ref: string;
                };
            };
            required: string[];
            title: string;
        };
        sortEnum: {
            type: string;
            enum: string[];
            additionalProperties: boolean;
            title: string;
        };
        FilterComponent: {
            type: string;
            properties: {
                column: {
                    type: string;
                };
                function: {
                    $ref: string;
                };
                args: {
                    type: string;
                };
            };
            required: string[];
            allOf: {
                if: {
                    properties: {
                        function: {
                            const: string;
                        };
                    };
                };
                then: {
                    properties: {
                        args: {
                            type: string;
                            items: {
                                $ref: string;
                            };
                        };
                    };
                };
            }[];
            title: string;
        };
        DatasetlookupGroup: {
            type: string;
            properties: {
                columnGroup: {
                    type: string;
                    properties: {
                        source: {
                            type: string;
                        };
                    };
                    required: string[];
                };
                groupFunctions: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
            };
            title: string;
        };
        ColumnGroupFunctions: {
            type: string;
            properties: {
                source: {
                    type: string;
                };
                function: {
                    type: string;
                    enum: string[];
                    additionalProperties: boolean;
                };
                column: {
                    type: string;
                };
            };
            required: string[];
            title: string;
        };
        NavTree: {
            type: string;
            properties: {
                root_items: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
            };
            required: string[];
            title: string;
        };
        RootItem: {
            type: string;
            properties: {
                type: {
                    type: string;
                };
                id: {
                    type: string;
                };
                name: {
                    type: string;
                };
                children: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
            };
            title: string;
        };
        Child: {
            type: string;
            properties: {
                page: {
                    type: string;
                };
            };
            title: string;
        };
        DataSetType: {
            type: string;
            enum: string[];
            title: string;
        };
        FunctionList: {
            type: string;
            enum: string[];
            title: string;
        };
        ChartProperties: {
            type: string;
            properties: {
                bgColor: {
                    type: string;
                };
                width: {
                    type: string[];
                };
                height: {
                    type: string[];
                };
                zoom: {
                    type: string[];
                };
                margin: {
                    type: string;
                    properties: {
                        right: {
                            type: string[];
                        };
                        top: {
                            type: string[];
                        };
                        bottom: {
                            type: string[];
                        };
                        left: {
                            type: string[];
                        };
                    };
                };
                resizable: {
                    type: string[];
                };
                legend: {
                    type: string;
                    properties: {
                        show: {
                            type: string[];
                        };
                        position: {
                            type: string;
                            enum: string[];
                        };
                    };
                };
                grid: {
                    type: string;
                    properties: {
                        x: {
                            type: string[];
                        };
                        y: {
                            type: string[];
                        };
                    };
                };
                general: {
                    type: string;
                    properties: {
                        visible: {
                            type: string[];
                        };
                        title: {
                            type: string;
                        };
                    };
                };
            };
        };
        CustomProperties: {
            type: string;
            description: string;
            additionalProperties: {};
        };
        DisplayerSettings: {
            type: string;
            properties: {
                lookup: {
                    $ref: string;
                };
                filter: {
                    $ref: string;
                };
                refresh: {
                    type: string;
                    properties: {
                        interval: {
                            type: string;
                        };
                    };
                    required: string[];
                    title: string;
                };
                renderer: {
                    type: string;
                    enum: string[];
                    additionalProperties: boolean;
                    title: string;
                };
                selector: {
                    type: string;
                    properties: {
                        multiple: {
                            type: string[];
                        };
                        inputs_show: {
                            type: string[];
                        };
                    };
                    required: string[];
                    title: string;
                };
                echarts: {
                    title: string;
                };
                general: {
                    type: string;
                    properties: {
                        title: {
                            type: string;
                        };
                        visible: {
                            type: string;
                        };
                        mode: {
                            $ref: string;
                        };
                        allowEdit: {
                            type: string;
                            title: string;
                        };
                    };
                    required: string[];
                    title: string;
                };
                export: {
                    type: string;
                    properties: {
                        png: {
                            type: string;
                        };
                    };
                    required: string[];
                    title: string;
                };
                columns: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                table: {
                    $ref: string;
                };
                html: {};
                javascript: {
                    type: string;
                };
                map: {
                    type: string;
                    properties: {
                        color_scheme: {
                            $ref: string;
                        };
                    };
                    title: string;
                };
                meter: {
                    $ref: string;
                };
                component: {
                    anyOf: ({
                        type: string;
                        $ref?: undefined;
                    } | {
                        $ref: string;
                        type?: undefined;
                    })[];
                };
                external: {
                    $ref: string;
                };
                bubble: {
                    type: string;
                    properties: {
                        minSize: {
                            type: string;
                        };
                        maxSize: {
                            type: string;
                        };
                        color: {
                            type: string;
                        };
                    };
                    required: string[];
                    title: string;
                };
                axis: {
                    type: string;
                    properties: {
                        x: {
                            type: string;
                            properties: {
                                labels_show: {
                                    type: string[];
                                };
                                title: {
                                    type: string;
                                };
                                labels_angle: {
                                    type: string[];
                                };
                            };
                            title: string;
                        };
                        y: {
                            type: string;
                            properties: {
                                labels_show: {
                                    type: string[];
                                };
                                title: {
                                    type: string;
                                };
                                labels_angle: {
                                    type: string[];
                                };
                            };
                            title: string;
                        };
                    };
                };
                type: {
                    $ref: string;
                };
                chart: {
                    $ref: string;
                };
            };
            allOf: {
                if: {
                    properties: {
                        type: {
                            const: string;
                        };
                    };
                };
                then: {
                    properties: {
                        subtype: {
                            $ref: string;
                        };
                    };
                };
            }[];
            title: string;
        };
        SettingsExternal: {
            type: string;
            properties: {
                baseUrl: {
                    type: string;
                };
                width: {};
                height: {};
            };
            title: string;
        };
        ChartType: {
            type: string;
            enum: string[];
            additionalProperties: boolean;
            title: string;
        };
        BarChartTypes: {
            type: string;
            enum: string[];
            default: string;
            additionalProperties: boolean;
            title: string;
        };
        LineChartTypes: {
            type: string;
            enum: string[];
            default: string;
            additionalProperties: boolean;
            title: string;
        };
        AreaChartTypes: {
            type: string;
            enum: string[];
            default: string;
            additionalProperties: boolean;
            title: string;
        };
        PieChartTypes: {
            type: string;
            enum: string[];
            default: string;
            additionalProperties: boolean;
            title: string;
        };
        SelectorTypes: {
            type: string;
            enum: string[];
            additionalProperties: boolean;
            title: string;
        };
        MeterTypes: {
            type: string;
            properties: {
                start: {
                    type: string;
                };
                end: {
                    type: string;
                };
                critical: {
                    type: string;
                };
                warning: {
                    type: string;
                };
            };
        };
        MapColorScheme: {
            type: string;
            enum: string[];
        };
        MapTypes: {
            type: string;
            enum: string[];
            additionalProperties: boolean;
        };
        NavComponentTypes: {
            type: string;
            enum: string[];
            additionalProperties: boolean;
        };
        SettingsComponent: {
            type: string;
            enum: string[];
        };
        ColourModes: {
            type: string;
            enum: string[];
            title: string;
            additionalProperties: boolean;
        };
    };
};
//# sourceMappingURL=dashbuilder.d.ts.map